@@ -32,7 +32,7 @@ create_dataset <- function(json_parametros, url) {
     test_call <- FALSE
   }
   if (test_call == 1) {
-    message("This is a TEST CALL, set \"test_call\" : \"off\" or remove to execute service.")
+    message("This is a TEST CALL, set \"test_call\"=\"off\" or remove to execute service.")
   }
   respuesta0 <- NULL
   #Creación del dataset
@@ -57,22 +57,26 @@ create_dataset <- function(json_parametros, url) {
       action <- "API_insertObservationsFromDataFrame"
       rownames(obj$df_nuevo) <- 1:n_filas
       for (i in seq(0, n_filas, by = tam_pedazo)) {
-        if ((n_filas - i) < tam_pedazo) {
-          tam_pedazo <- (n_filas - i)
-        }
-        df_nuevo <- obj$df_nuevo[(i + 1) : (i + tam_pedazo), ]
-        json_particion[nom_obs] <- toJSON(df_nuevo, dataframe = "columns")
-        data <- list(action = action, json = json_particion)
-        respuesta <- dameRespuestaLlamado(url, data)
-        #Imprimir avance
-        avance <- round(((i + tam_pedazo) / n_filas) * 100, digits = 2)
-        if (avance > 100) {
-          message("100%")
-          message("Wrapping Up..")
-        } else {
-          message(paste(avance, "%"))
-          Sys.sleep(2)
-        }
+        tryCatch({
+          if ((n_filas - i) < tam_pedazo) {
+            tam_pedazo <- (n_filas - i)
+          }
+          df_nuevo <- obj$df_nuevo[(i + 1) : (i + tam_pedazo), ]
+          json_particion[nom_obs] <- toJSON(df_nuevo, dataframe = "columns")
+          data <- list(action = action, json = json_particion)
+          respuesta <- dameRespuestaLlamado(url, data)
+          #Imprimir avance
+          avance <- round(((i + tam_pedazo) / n_filas) * 100, digits = 2)
+          if (avance > 100) {
+            message("100%")
+            message("Wrapping Up..")
+          } else {
+            message(paste(avance, "%"))
+            Sys.sleep(2)
+          }
+        }, error = function(e) {
+          message("Some observations might not have been uploaded.")
+        })
       }
     } else {
       df_nuevo <- obj$df_nuevo[sample(nrow(obj$df_nuevo), tam_pedazo_ini), ]
