@@ -34,17 +34,13 @@
 # ############################################################
 # #####################Obtain observations####################
 action <- "API_getObservationsFromDataset"
+# DATASET: 'BBC News Business headlines'
 parameters <- list(
-  oblender = 1,
-  blends = list(list(id_blend = "5d976070f86334ee1cfc14f0", blend_type = "ts", restriction = "None", blend_class = "closest_observation")),
-  token = "67dTvR8KVRM044s9ldE94IgFc5HF3q",
-  id_user = "5d48b439275b3f05db0feee2",
-  id_dataset = "5d533b864b81b70af19bdc4c"
+  token="5d07bed33e59b27a93e43be804ij5qcy5ss9jHsoBpwpxsvLZqyrcU",
+  id_user="5d07bed33e59b27a93e43be8",
+  id_dataset="5d82477f951629088f08cef5",
+  sample_size=200
 )
-
-response <- openblender::call(action, parameters)
-dfr <- response$sample
-head(dfr)
-nrow(dfr)
-# dfr
+df <- openblender::call(action, parameters)$sample
+head(df)
 
